@@ -9,12 +9,14 @@ import os
 import requests
 from retrying import retry
 
-from anole import setting
+from anole import setting, error
 
 
 @retry(stop_max_attempt_number=setting.HTTP_RETRY)
 def get(url):
     res = requests.get(url)
+    if res.status_code != "200":
+        raise error.AnoleCrawlError("Download cache failed, please check.")
     return res
 
 
@@ -31,4 +33,3 @@ def load_cached(path):
     if not os.path.exists(path):
         update(path, get(setting.CACHE_URL).text)
     return read(path)
-
